@@ -44,15 +44,19 @@ function(
   
   all.data <- rbind(new.data, old.data)
 
-  results <- list(configural = NA, weak = NA, strong = NA, strict = NA)
-  models <- list(configural = NA, weak = NA, strong = NA, strict = NA)
-  
+  results <- models <- list(configural = NA, weak = NA, strong = NA, strict = NA)
+
+  if (all(sapply(all.data[, unlist(selection$subtests)], is.ordered))) {
+    results$strict <- models$strict <- NULL
+    warning('Strict measurement invariance is not implemented for exclusively ordinal indicators.', call. = FALSE)
+  }
+    
   for (invariance in names(results)) {
     pars <- parameters
     
     equality <- character()
     if (invariance%in%c('weak','strong','strict')) equality <- c(equality,'=~')
-    if (invariance%in%c('strong','strict')) equality <- c(equality,'~1')
+    if (invariance%in%c('strong','strict')) equality <- c(equality,'~1', '|')
     if (invariance%in%c('strict')) equality <- c(equality,'~~')
     
     tmp <- pars[pars$label != '' & !pars$op%in%equality, ]
@@ -80,19 +84,23 @@ function(
     args <- list(data=all.data,selected.items=selection$subtests,
       grouping=grouping,auxi=all.data[,NULL],suppress.model=TRUE,
       analysis.options=analysis.options,objective=selection$parameters$objective,ignore.errors=TRUE,
-      output.model=FALSE,factor.structure=selection$parameters$factor.structure)
+      output.model=TRUE,factor.structure=selection$parameters$factor.structure)
     
     results[[invariance]] <- do.call('run.lavaan',args)
+    models[[invariance]] <- results[[invariance]]$model
+    if (is.null(models[[invariance]])) models[[invariance]] <- NA
+    
     results[[invariance]] <- as.data.frame(fitness(selection$parameters$objective, results[[invariance]], 'lavaan'))
     
-    args$output.model <- TRUE
-    models[[invariance]] <- do.call('run.lavaan',args)
-    
-    
   }
 
   results <- do.call(rbind, results)
-  comps <- do.call(lavaan::lavTestLRT, c(object=models[[1]], models[-1]))
+  comps <- try(do.call(lavaan::lavTestLRT, c(object=models[[1]], models[-1])), silent = TRUE)
+  if (class(comps)[1]=='try-error') {
+    comps <- matrix(NA, ncol = 7, nrow = 4)
+    colnames(comps)[5:7] <- c('Chisq diff', 'Df diff', 'Pr(>Chisq)')
+    warning('One or more of the models resulted in an error. The LRT cannot be computed.', call. = FALSE)
+  }
   rownames(comps) <- names(models)
   results <- cbind(results, comps[, 5:7])
   output <- list(comparison = results, models = models)
